FastPubAck

Struct FastPubAck 

pub struct FastPubAck {
    pub batch_sequence: u64,
    pub ack_sequence: u64,
}
Result of a successful FastPublisher::add / FastPublisher::add_message call.

The ack_sequence is the highest batch sequence acknowledged by the server so far. In GapMode::Fail this means all messages up to and including ack_sequence were persisted. In GapMode::Ok there may have been gaps; ack_sequence is only a hint about how far the server has progressed.

Fields

batch_sequence: u64

Batch sequence of the message that was just added.

ack_sequence: u64

Highest batch sequence acknowledged by the server so far.